"""Import svg_strings into the svg_ultralight.strings namespace.

:author: Shay Hill
:created: 2021-12-09
"""

from svg_ultralight.strings.svg_strings import (
    svg_color_tuple,
    svg_float_tuples,
    svg_ints,
)

__all__ = ["svg_color_tuple", "svg_float_tuples", "svg_ints"]
